#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-hunit
version:              0.3.0.2
visibility:           public
id:                   test-framework-hunit-0.3.0.2-JqfyBC8mbaa89IkXUXIb9m
key:                  test-framework-hunit-0.3.0.2-JqfyBC8mbaa89IkXUXIb9m
license:              BSD-3-Clause
maintainer:           Haskell Libraries <libraries@haskell.org>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             https://batterseapower.github.io/test-framework/
synopsis:             HUnit support for the test-framework package.
description:          HUnit support for the test-framework package.
category:             Testing
abi:                  0b04daa4a358e487d2960c0c43fb6044
exposed:              True
exposed-modules:      Test.Framework.Providers.HUnit
import-dirs:          /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/test-framework-hunit-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-hunit
hs-libraries:         HStest-framework-hunit-0.3.0.2-JqfyBC8mbaa89IkXUXIb9m
depends:
    HUnit-1.6.2.0-DydRkK1Ty562EFYgxreweA base-4.18.2.1
    extensible-exceptions-0.1.1.4-7NlwspXgM9LGnBo916NhuH
    test-framework-0.8.2.3-CINrFundNfO38U6yQoXuh4

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

